pub struct EmulatorState {
pub memory: [u8; 4096],
pub stack: Vec<usize>,
pub variable_registers: [u8; 16],
pub screen_buffer: Vec<u8>,
pub index_register: usize,
pub program_counter: usize,
pub last_instruction: Instruction,
pub delay_timer: u16,
pub sound_timer: u16,
pub width: usize,
pub height: usize,
}Expand description
Data that is returned after each iteration of the interpreter as long as it is running as an iterator.
Fields
memory: [u8; 4096]stack: Vec<usize>variable_registers: [u8; 16]screen_buffer: Vec<u8>index_register: usizeprogram_counter: usizelast_instruction: Instructiondelay_timer: u16sound_timer: u16width: usizeheight: usizeTrait Implementations
Sourceimpl Clone for EmulatorState
impl Clone for EmulatorState
Sourcefn clone(&self) -> EmulatorState
fn clone(&self) -> EmulatorState
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EmulatorState
impl Debug for EmulatorState