pub struct EmulatorState {
pub memory: [u8; 4096],
pub stack: Vec<usize>,
pub variable_registers: [u8; 16],
pub screen_buffer: Vec<u8>,
pub index_register: usize,
pub program_counter: usize,
pub last_instruction: Instruction,
}Expand description
Data that is returned after each iteration of the interpreter as long as it is running as an iterator.
Fields
memory: [u8; 4096]stack: Vec<usize>variable_registers: [u8; 16]screen_buffer: Vec<u8>index_register: usizeprogram_counter: usizelast_instruction: InstructionTrait Implementations